summaryrefslogtreecommitdiff
path: root/gcc/bitmap.c
diff options
context:
space:
mode:
authorlaw <law@138bc75d-0d04-0410-961f-82ee72b054a4>1999-09-20 11:52:22 +0000
committerlaw <law@138bc75d-0d04-0410-961f-82ee72b054a4>1999-09-20 11:52:22 +0000
commit64c25516b35708e47ddd19b659b65e5b98f7afe9 (patch)
treea5343f51ad867f827443536e7582ba9aefd6b06b /gcc/bitmap.c
parent89c912f6f274f9bbe74a24e55122c10e18450839 (diff)
downloadgcc-64c25516b35708e47ddd19b659b65e5b98f7afe9.tar.gz
* bitmap.c (debug_bitmap_file): Renmaed from bitmap_debug_file.
Callers and prototype changed. * bitmap.h: Fix debug_bitmap and debug_bitmap_file prototypes. git-svn-id: svn+ssh://gcc.gnu.org/svn/gcc/trunk@29518 138bc75d-0d04-0410-961f-82ee72b054a4
Diffstat (limited to 'gcc/bitmap.c')
-rw-r--r--gcc/bitmap.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/gcc/bitmap.c b/gcc/bitmap.c
index b6d1dbf2f67..3c29c44c4d9 100644
--- a/gcc/bitmap.c
+++ b/gcc/bitmap.c
@@ -552,7 +552,7 @@ bitmap_initialize (head)
/* Debugging function to print out the contents of a bitmap. */
void
-bitmap_debug_file (file, head)
+debug_bitmap_file (file, head)
FILE *file;
bitmap head;
{
@@ -602,10 +602,10 @@ void
debug_bitmap (head)
bitmap head;
{
- bitmap_debug_file (stdout, head);
+ debug_bitmap_file (stdout, head);
}
/* Function to print out the contents of a bitmap. Unlike bitmap_debug_file,
it does not print anything but the bits. */
void
@@ -602,10 +602,10 @@ void
}
-/* Function to print out the contents of a bitmap. Unlike bitmap_debug_file,
+/* Function to print out the contents of a bitmap. Unlike debug_bitmap_file,
it does not print anything but the bits. */
void